@@ -86,7 +86,7 @@ class AutoPollingCachePolicy(CachePolicy):
             if not self._initialized and old_configuration is not None:
                 self._initialized = True
         except HTTPError as e:
-            log.error('Double-check your API KEY at https://app.configcat.com/apikey.'
+            log.error('Double-check your SDK Key at https://app.configcat.com/sdkkey.'
                       ' Received unexpected response: %s' % str(e.response))
         except:
             log.exception(sys.exc_info()[0])
