@@ -1,25 +1,6 @@
 from abc import ABCMeta, abstractmethod
 
 
-class ConfigFetcher(object):
-    """
-        Config fetcher interface
-    """
-    __metaclass__ = ABCMeta
-
-    @abstractmethod
-    def get_configuration_json(self):
-        """
-        :return: Returns the configuration json Dictionary
-        """
-
-    @abstractmethod
-    def close(self):
-        """
-            Closes the ConfigFetcher's resources
-        """
-
-
 class ConfigCache(object):
     """
         Config cache interface
